@@ -1,4 +1,4 @@
-# $Id: Empty.pm,v 1.7 2006/04/21 21:17:54 Daddy Exp $
+# $Id: Empty.pm,v 1.8 2007/05/15 12:04:20 Daddy Exp $
 
 =head1 NAME
 
@@ -32,9 +32,10 @@ package WWW::Search::Null::Empty;
 
 use strict;
 
-use vars qw( @ISA $VERSION );
-@ISA = qw( WWW::Search );
-$VERSION = do { my @r = (q$Revision: 1.7 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+use base 'WWW::Search';
+our
+$VERSION = do { my @r = (q$Revision: 1.8 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+our $MAINTAINER = q{Martin Thurn <mthurn@cpan.org>};
 
 sub _native_setup_search
   {
