@@ -1,5 +1,5 @@
 
-# $Id: Result.pm,v 1.3 2005/12/25 15:06:21 Daddy Exp $
+# $Id: Result.pm,v 1.4 2007/06/03 19:31:27 Daddy Exp $
 
 =head1 NAME
 
@@ -17,13 +17,12 @@ Martin Thurn
 
 package WWW::Search::Result;
 
-use WWW::SearchResult;
-
 use strict;
-use vars qw( @ISA $VERSION );
 
-@ISA = qw( WWW::SearchResult );
-$VERSION = do { my @r = (q$Revision: 1.3 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+use base 'WWW::SearchResult';
+
+our
+$VERSION = do { my @r = (q$Revision: 1.4 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 
 1;
 
